package com.br.fechadura.mobile.ui.screens

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.Create
import androidx.compose.material.icons.filled.Person
import androidx.compose.material3.AlertDialog
import androidx.compose.material3.Button
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import coil.compose.rememberAsyncImagePainter
import com.br.fechadura.mobile.R
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.viewModel.MainViewModel

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun PerfilScreen(navController: NavController) {
    val showAlert = remember { mutableStateOf(false) }

    val perfilViewModel = viewModel<MainViewModel>()
    val perfilLocal by perfilViewModel.perfilLocal

    Scaffold(
        topBar = {
            TopAppBar(
                title = { Text(perfilLocal.nome, color = Color.White) },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor
                ),
                navigationIcon = {
                    IconButton(onClick = { navController.navigate("inicio") }) {
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar para início",
                            tint = Color.White
                        )
                    }
                }
            )
        }
    ) { innerPadding ->
            Column(
                modifier = Modifier
                    .padding(innerPadding)
                    .padding(top = 15.dp)
                    .verticalScroll(rememberScrollState())
                    .fillMaxSize(),
                verticalArrangement = Arrangement.spacedBy(15.dp),
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Text(
                    text = "Minha conta",
                    style = MaterialTheme.typography.headlineMedium,
                    color = Color.Black
                )
                if (perfilLocal.link_foto.isNullOrEmpty()) {
                    // Mostrar ícone padrão se não houver imagem
                    Box(
                        modifier = Modifier.padding(16.dp)
                    ) {
                        Image(
                            modifier = Modifier.clip(shape = CircleShape),
                            contentDescription = "Foto de perfil",
                            painter = painterResource(id = R.drawable.macaco)
                        )
                        Button(
                            onClick = {

                            },
                            shape = CircleShape,
                            contentPadding = PaddingValues(0.dp),
                            modifier = Modifier
                                .size(50.dp)
                                .align(Alignment.BottomEnd)
                        ) {
                            Icon(Icons.Default.Create, contentDescription = "ícone de lupa")
                        }
                    }
                } else {
                    // Carregar a imagem do usuário
                    Image(
                        painter = rememberAsyncImagePainter(perfilLocal.link_foto),
                        contentDescription = "Avatar do usuário",
                        modifier = Modifier
                            .size(50.dp)
                            .clip(CircleShape)
                            .background(Color.Gray),
                        contentScale = ContentScale.Crop
                    )
                }

                Text(
                    style = MaterialTheme.typography.headlineSmall,
                    text = perfilLocal.nome,
                    color = Color.Black
                )
                Text(
                    text = perfilLocal.email,
                    style = TextStyle(
                        fontSize = MaterialTheme.typography.bodySmall.fontSize,
                        color = Color.Gray
                    )
                )
                Button(
                    onClick = {
                        showAlert.value = true
                    },
                    modifier = Modifier.padding(top = 24.dp)
                ) { Text(text = "Sair") }
            }

            if (showAlert.value) {
                AlertDialog(onDismissRequest = {
                    showAlert.value = false
                },
                    title = {
                        Text(text = "Tem certeza que deseja sair?")
                    },
                    text = {
                        Text("Não será possível acessar informações e receber notificações pessoais.")
                    },
                    confirmButton = {
                        Button(
                            onClick = {
                                showAlert.value = false
                                navController.navigate("login")
                            }
                        ) {
                            Text(text = "Sair")
                        }
                    },
                    dismissButton = {
                        Button(
                            onClick = {
                                showAlert.value = false
                            }
                        ) {
                            Text("Cancelar")
                        }
                    }
                )
            }
    }
}

@Preview
@Composable
private fun preview() {
    PerfilScreen(navController = rememberNavController())
}