package com.br.fechadura.mobile.ui.screens.grupoPortas

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.Search
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.vini.compose.api.ApiState
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.Alignment
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.br.fechadura.mobile.ui.screens.FailScreen
import com.br.fechadura.mobile.ui.screens.LoadingScreen
import com.br.fechadura.mobile.ui.theme.Branco
import com.br.fechadura.mobile.ui.theme.FundoFechaduraColor
import com.br.fechadura.mobile.viewModel.GrupoPortasViewModel

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun GrupoPortaScreen(
    navController: NavController
) {
    var text by remember { mutableStateOf("") }

    val grupoPortaViewModel: GrupoPortasViewModel = viewModel()
    val grupoState by grupoPortaViewModel.grupoPortasResponseBody

    Scaffold(
        topBar = {
            TopAppBar(
                navController = navController,
                title = "Grupo de Portas",
                searchText = text,
                onSearchChange = { text = it },
                showSearchIcon = false,
                showBackButton = false
            )
        },
        floatingActionButton = {
            FloatingActionButton(
                onClick = { navController.navigate("cadastrar-grupo-porta") },
                containerColor = FechaduraColor
            ) {
                Icon(Icons.Default.Add, contentDescription = "Add", tint = Branco)
            }
        }
    ) { innerPadding ->
        Box(
            modifier = Modifier
                .fillMaxSize()
                .padding(innerPadding)
        ) {
            Column(
                modifier = Modifier
                    .fillMaxSize()
            ) {
                when (grupoState) {
                    is ApiState.Created -> {}
                    is ApiState.Loading -> {
                        if (grupoState.data?.data.isNullOrEmpty()) {
                            LoadingScreen()
                        }
                    }

                    is ApiState.Success -> {
                        grupoState.data?.let { responseData ->
                            if (responseData.data.isEmpty()) {
                                Text(text = "Nenhum grupo de portas")
                            } else {
                                LazyColumn(
                                    modifier = Modifier
                                        .fillMaxSize()
                                        .background(Color.White)
                                ) {
                                    item {
                                        SearchBar(
                                            modifier = Modifier
                                                .padding(10.dp)
                                                .fillMaxWidth(),
                                            query = text,
                                            onQueryChange = {
                                                text = it
                                            },
                                            onSearch = {},
                                            active = false,
                                            onActiveChange = {},
                                            colors = SearchBarDefaults.colors(
                                                containerColor = FundoFechaduraColor
                                            ),
                                            placeholder = { Text("Buscar grupo") },
                                            leadingIcon = {
                                                Icon(
                                                    Icons.Default.Search,
                                                    contentDescription = null
                                                )
                                            },

                                            ) {
                                        }
                                    }
                                    items(
                                        items = responseData.data.filter {
                                            it.nome.contains(text, ignoreCase = true)
                                        },
                                        key = { grupo -> grupo._id }
                                    ) { grupo ->
                                        Row(
                                            horizontalArrangement = Arrangement.SpaceBetween,
                                            modifier = Modifier
                                                .fillMaxWidth()
                                                .weight(1f)
                                                .clickable {
                                                    navController.navigate("visualizar-grupo-porta/${grupo._id}")
                                                }
                                                .padding(20.dp),
                                            verticalAlignment = Alignment.CenterVertically,

                                        ) {

                                            Text(text = grupo.nome, color = Color.Black)
                                            Text(
                                                text = if (grupo.ativo) "Ativo" else "Não Ativo",
                                                fontSize = 12.sp,
                                                color = if (grupo.ativo) FechaduraColor else Color.Red
                                            )
                                        }
                                    }
                                }
                            }
                        }
                    }

                    is ApiState.Error -> {
                        grupoState.message?.let { message ->
                            FailScreen(message)
                        }
                    }
                }
            }
        }
    }

    // Carregamento inicial
    LaunchedEffect(Unit) {
        grupoPortaViewModel.getGrupoPortas()
    }
}
