package com.br.fechadura.mobile.ui.screens.usuario

import android.icu.text.UnicodeSet.SpanCondition
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Edit
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material.icons.filled.Person
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.Color.Companion.Black
import androidx.compose.ui.graphics.Color.Companion.Gray
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.api.response.GrupoUsuarioResponseBody

import com.br.fechadura.mobile.ui.screens.FailScreen
import com.br.fechadura.mobile.ui.screens.LoadingScreen
import com.br.fechadura.mobile.viewModel.UsuariosViewModel
import com.br.vini.compose.api.ApiState
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.onPrimaryLight
import com.br.fechadura.mobile.ui.theme.primaryContainerLight
import com.br.fechadura.mobile.ui.theme.primaryLight
import com.br.fechadura.mobile.ui.theme.secondaryLight
import com.br.fechadura.mobile.ui.theme.surfaceContainerLight
import com.br.fechadura.mobile.viewModel.GrupoUsuariosViewModel
import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun VisualizarGrupoUsuario(
    id: String,
    navController: NavController
) {

    val grupoViewModel = viewModel<GrupoUsuariosViewModel>()
    val grupostate by grupoViewModel.grupoUsuarioResponse

    LaunchedEffect(id) {
        grupoViewModel.getGrupoUsuarioById(id)
    }

    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Text(grupostate.data?.data?.nome ?: "Visualizar Grupo")
                },
                navigationIcon = {
                    IconButton(onClick = { navController.popBackStack() }) { // Volta para a página anterior
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar",
                            tint = Color.White
                        )
                    }
                },
                actions = {
                    IconButton(onClick = { navController.navigate("editar-grupo-usuario/${id}") }) { // Ação de edição
                        Icon(
                            imageVector = Icons.Default.Edit,
                            contentDescription = "Editar",
                            tint = Color.White
                        )
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor,
                    actionIconContentColor = Gray,
                    navigationIconContentColor = Gray,
                    scrolledContainerColor = Gray,
                    titleContentColor = Color.White
                )
            )
        },
        containerColor = Color.White,
        modifier = Modifier.fillMaxSize()
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(innerPadding)
                .padding(16.dp),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Top
        ) {
            when (grupostate) {
                is ApiState.Error -> {}
                is ApiState.Created -> {}
                is ApiState.Loading -> {
                    LoadingScreen()
                }
                is ApiState.Success -> {
                    grupostate.data?.data?.let { grupoUsuario ->
                        LazyColumn(modifier = Modifier.fillMaxSize()) {
                            item {
                                Column(
                                    modifier = Modifier
                                        .padding(top = 25.dp),
                                    horizontalAlignment = Alignment.CenterHorizontally
                                ) {
                                Text(
                                    text = grupoUsuario.nome,
                                    fontSize = 24.sp,
                                    fontWeight = FontWeight.Bold,
                                    modifier = Modifier.padding(bottom = 16.dp)
                                )
                                // Descrição do grupo
                                Text(
                                    text = grupoUsuario.descricao,
                                    fontSize = 16.sp,
                                    color = Color.Gray,
                                    textAlign = TextAlign.Center,
                                    modifier = Modifier
                                        .fillMaxWidth()
                                        .padding(bottom = 24.dp)
                                )
                                // Status Ativo
                                Text(
                                    text = if (grupoUsuario.ativo) "Ativo" else "Inativo",
                                    fontSize = 16.sp,
                                    fontWeight = FontWeight.Bold,
                                    color = if (grupoUsuario.ativo) FechaduraColor else Color.Red,
                                    modifier = Modifier
                                        .padding(bottom = 24.dp)
                                )

                                Text(
                                    text = "Portas do grupo",
                                    fontWeight = FontWeight.Bold,
                                    fontSize = 16.sp,
                                    color = Color.Black,
                                    modifier = Modifier.padding(bottom = 8.dp)
                                )

                                if (grupoUsuario.grupoPortas.isNotEmpty()) {
                                    grupoUsuario.grupoPortas.forEach { grupoPorta ->
                                        grupoPorta.portas.forEach { porta ->
                                            Row(
                                                modifier = Modifier
                                                    .fillMaxWidth()
                                                    .height(76.dp)
                                                    .padding(top = 16.dp)
                                                    .background(
                                                        color = surfaceContainerLight,
                                                        shape = RoundedCornerShape(8.dp)
                                                    ),
                                                verticalAlignment = Alignment.CenterVertically
                                            ) {
                                                Text(
                                                    text = porta.descricao,
                                                    modifier = Modifier.padding(start = 20.dp)
                                                )
                                            }
                                        }
                                    }
                                } else {
                                    // Caso não haja portas, exiba uma mensagem
                                    Text(
                                        text = "Nenhuma porta disponível",
                                        fontSize = 16.sp,
                                        color = Color.Black,
                                        modifier = Modifier.padding(top = 16.dp)
                                    )
                                }
                            }
                        }
                        }
                    }
                }
            }
        }
    }
}

// Modelo de dados para exemplo
data class GrupoUsuario(
    val nome: String,
    val descricao: String,
    val ativo: Boolean,
    val portas: List<String>
)

@Preview(showSystemUi = true)
@Composable
private fun PreviewVisualizarGrupoUsuario() {
    VisualizarGrupoUsuario(
        id = "1",
        navController = rememberNavController()
    )
}

