package com.br.fechadura.mobile.ui.screens.usuario

import android.icu.text.UnicodeSet.SpanCondition
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Edit
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material.icons.filled.Person
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.Color.Companion.Black
import androidx.compose.ui.graphics.Color.Companion.Gray
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import coil.compose.rememberAsyncImagePainter
import com.br.fechadura.mobile.ui.screens.FailScreen
import com.br.fechadura.mobile.ui.screens.LoadingScreen
import com.br.fechadura.mobile.viewModel.UsuariosViewModel
import com.br.vini.compose.api.ApiState
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.surfaceContainerLight
import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun VisualizarUsuario(
    id: String,
    navController: NavController
) {
    val usuarioViewModel = viewModel<UsuariosViewModel>()
    val usuarioState by usuarioViewModel.usuarioResponse

    LaunchedEffect(id) {
        usuarioViewModel.getUsuarioById(id)
    }
    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Text(usuarioState.data?.data?.nome ?: "Visualizar Usuário")
                },
                navigationIcon = {
                    IconButton(onClick = { navController.popBackStack() }) { // Volta para a página anterior
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar",
                            tint = Color.White
                        )
                    }
                },
                actions = {
                    IconButton(onClick = { navController.navigate("editar-usuario/${usuarioState.data?.data?._id}") }) { // Ação de edição
                        Icon(
                            imageVector = Icons.Default.Edit,
                            contentDescription = "Editar",
                            tint = Color.White
                        )
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor,
                    actionIconContentColor = Gray,
                    navigationIconContentColor = Gray,
                    scrolledContainerColor = Gray,
                    titleContentColor = Color.White
                )
            )
        },
        containerColor = Color.White,
        modifier = Modifier.fillMaxSize()
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(innerPadding)
                .padding(16.dp),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Top
        ) {
            when (usuarioState) {
                is ApiState.Created -> {}
                is ApiState.Loading -> {
                    LoadingScreen()
                }

                is ApiState.Success -> {
                    usuarioState.data?.let { usuario ->
                        LazyColumn(
                            modifier = Modifier
                                .fillMaxSize()
                        ) {
                            item {
                                Column(
                                    modifier = Modifier
                                        .fillMaxSize()
                                        .padding(top = 25.dp),
                                    horizontalAlignment = Alignment.CenterHorizontally
                                ) {
                                    if (usuario.data.link_foto.isNullOrEmpty()) {
                                        // Mostrar ícone padrão se não houver imagem
                                        Box(
                                            modifier = Modifier
                                                .size(100.dp)
                                                .clip(CircleShape)
                                                .background(Color.Gray),
                                            contentAlignment = Alignment.Center,
                                        ) {
                                            Icon(
                                                imageVector = Icons.Default.Person,
                                                contentDescription = "User Avatar",
                                                modifier = Modifier.size(80.dp),
                                                tint = Color.Black
                                            )
                                        }
                                    } else {
                                        // Carregar a imagem do usuário
                                        Image(
                                            painter = rememberAsyncImagePainter(usuario.data.link_foto),
                                            contentDescription = "Avatar do usuário",
                                            modifier = Modifier
                                                .size(100.dp)
                                                .clip(CircleShape)
                                                .background(Color.Gray),
                                            contentScale = ContentScale.Crop
                                        )
                                    }
                                    Spacer(modifier = Modifier.height(15.dp))
                                    Column(
                                        horizontalAlignment = Alignment.CenterHorizontally
                                    ) {

                                        Text(
                                            text = usuario.data.nome,
                                            fontSize = 20.sp,
                                            fontWeight = FontWeight.Bold
                                        )

                                        Spacer(modifier = Modifier.height(5.dp))

                                        usuario.data.email.let {
                                            Text(
                                                text = it,
                                                fontSize = 16.sp,
                                                color = Color.Gray
                                            )
                                        }

                                        Spacer(modifier = Modifier.height(5.dp))

                                        Text(
                                            text = if (usuario.data.ativo) "Ativo" else "Inativo",
                                            fontSize = 16.sp,
                                            fontWeight = FontWeight.Bold,
                                            color = if (usuario.data.ativo) FechaduraColor else Color.Red
                                        )

                                        Spacer(modifier = Modifier.height(45.dp))

                                        Column(
                                            modifier = Modifier.fillMaxWidth(),
                                            horizontalAlignment = Alignment.Start
                                        ) {
                                            Text(text = "Código de acesso", color = Color.Black)
                                            usuario.data.codigo_acesso?.let {
                                                Text(
                                                    text = usuario.data.codigo_acesso,
                                                    color = Black,
                                                    fontWeight = FontWeight.Bold
                                                )
                                            }
                                        }

                                        Spacer(modifier = Modifier.height(30.dp))
                                        
                                        Column(
                                            modifier = Modifier.fillMaxWidth(),
                                            horizontalAlignment = Alignment.Start
                                        ) {
                                            Text(text = "Grupo de Usuario", color = Color.Black)
                                            if (usuario.data.grupoUsuarios?.isNotEmpty() == true) {
                                                usuario.data.grupoUsuarios.forEach { grupo ->
                                                    Text(
                                                        text = grupo.nome,
                                                        color = Black,
                                                        fontWeight = FontWeight.Bold
                                                    )
                                                }
                                            } else {
                                                Text(
                                                    text = "Nenhum grupo",
                                                    color = Black,
                                                    fontWeight = FontWeight.Bold
                                                )
                                            }
                                        }

                                        Spacer(modifier = Modifier.height(30.dp))
                                        Column {
                                        Text(
                                            text = "Portas com acesso",
                                            fontWeight = FontWeight.Bold,
                                            fontSize = 16.sp
                                        )
                                        if (usuario.data.portas?.isNotEmpty() == true) {
                                            usuario.data.portas.forEach { porta ->
                                                Row(
                                                    modifier = Modifier
                                                        .fillMaxWidth()
                                                        .height(76.dp)
                                                        .padding(top = 16.dp)
                                                        .background(
                                                            color = surfaceContainerLight,
                                                            shape = RoundedCornerShape(8.dp)
                                                        ),
                                                    verticalAlignment = Alignment.CenterVertically
                                                ) {
                                                    Text(
                                                        text = porta.descricao,
                                                        modifier = Modifier.padding(start = 20.dp)
                                                    )
                                                }
                                            }
                                        } else {
                                            usuario.data.grupoUsuarios?.forEach { grupo ->
                                                grupo.grupoPortas.forEach { grupoPorta ->
                                                    grupoPorta.portas.forEach { porta ->
                                                        Row(
                                                            modifier = Modifier
                                                                .fillMaxWidth()
                                                                .height(76.dp)
                                                                .padding(top = 16.dp)
                                                                .background(
                                                                    color = surfaceContainerLight,
                                                                    shape = RoundedCornerShape(8.dp)
                                                                ),
                                                            verticalAlignment = Alignment.CenterVertically
                                                        ) {
                                                            Text(
                                                                text = porta.descricao,
                                                                modifier = Modifier.padding(start = 20.dp)
                                                            )
                                                        }
                                                    }
                                                }
                                            }

                                        }
                                    }
                                    }
                                }
                            }
                        }
                    } ?: run {
                        Text(text = "Usuário não encontrado")
                    }
                }
                is ApiState.Error -> {
                    usuarioState.message?.let { message ->
                        FailScreen(message)
                    }
                }
            }
        }
    }
}

@Preview(showSystemUi = true)
@Composable
private fun UserProfileScreen() {
    Column(
        modifier = Modifier
            .fillMaxSize()
    )
    {
        Row(
            modifier = Modifier
                .fillMaxWidth()
                .padding(10.dp)
                .height(70.dp)
                .border(
                    width = 1.dp,
                    color = FechaduraColor,
                    shape = RoundedCornerShape(8.dp)
                )
                .background(
                    color = Color.LightGray,
                    shape = RoundedCornerShape(8.dp)
                ),
            verticalAlignment = Alignment.CenterVertically
        ) {
            Text(
                text = "Vinicius Daniel Monteiro",
                fontSize = 20.sp,
                modifier = Modifier.padding(start = 10.dp)
            )
        }

    }
}